@@ -990,20 +990,16 @@ int mutt_compose_menu (HEADER *msg,   /* structure for new message */
        if (mutt_enter_fname (_("Write message to mailbox"), fname, sizeof (fname),
                              &menu->redraw, 1) != -1 && fname[0])
        {
-	 int oldhdrdate;
          mutt_message (_("Writing message to %s ..."), fname);
          mutt_expand_path (fname, sizeof (fname));
 
          if (msg->content->next)
            msg->content = mutt_make_multipart (msg->content);
 
-	 oldhdrdate = option(OPTUSEHEADERDATE);
-	 set_option(OPTUSEHEADERDATE);
          if (mutt_write_fcc (NONULL (fname), msg, NULL, 1, NULL) < 0)
            msg->content = mutt_remove_multipart (msg->content);
          else
            mutt_message _("Message written.");
-	 if(!oldhdrdate) unset_option(OPTUSEHEADERDATE);
        }
        break;
 
