@@ -245,7 +245,6 @@ enum
 #define SENDBATCH	(1<<5)
 #define SENDMAILX	(1<<6)
 #define SENDKEY		(1<<7)
-#define SENDEDITMSG	(1<<8)
 
 /* boolean vars */
 enum
@@ -347,7 +346,6 @@ enum
   OPTFORCEREDRAWPAGER,	/* (pseudo) used to force a redraw in the pager */
   OPTSORTSUBTHREADS,	/* (pseudo) used when $sort_aux changes */
   OPTNEEDRESCORE,	/* (pseudo) set when the `score' command is used */
-  OPTUSEHEADERDATE,	/* (pseudo) used by edit-message */
   OPTATTACHMSG,		/* (pseudo) used by attach-message */
   
 
@@ -545,7 +543,10 @@ typedef struct header
   struct header *last_sort; /* last message in subthread, for secondary SORT_LAST */
   char *tree;            /* character string to print thread tree */
 
-  
+
+#ifdef USE_IMAP
+  void *data;            /* driver-specific data (only used by IMAP */
+#endif
 } HEADER;
 
 #include "mutt_regex.h"
