@@ -98,11 +98,10 @@ static int dotlock_file (const char *path, int retry)
 {
   int r;
   int flags = DL_FL_USEPRIV | DL_FL_RETRY;
-  
+
   if (retry) retry = 1;
 
 retry_lock:
-  mutt_clear_error();
   if ((r = invoke_dotlock(path, flags, retry)) == DL_EX_EXIST)
   {
     if (!option (OPTNOCURSES))
@@ -115,6 +114,7 @@ retry_lock:
       {
 	flags |= DL_FL_FORCE;
 	retry--;
+	mutt_clear_error ();
 	goto retry_lock;
       }
     } 
@@ -727,7 +727,7 @@ static int sync_mailbox (CONTEXT *ctx)
 #ifdef USE_IMAP
     case M_IMAP:
       /* extra argument means EXPUNGE */
-      rc = imap_sync_mailbox (ctx, M_YES);
+      rc = imap_sync_mailbox (ctx, 1);
       break;
 #endif /* USE_IMAP */
   }
@@ -859,30 +859,43 @@ int mx_close_mailbox (CONTEXT *ctx)
     return 0;
   }
   
-  if (!purge)
+#ifdef USE_IMAP
+  /* allow IMAP to preserve the deleted flag across sessions */
+  if (ctx->magic == M_IMAP)
   {
-    for (i = 0; i < ctx->msgcount; i++)
-      ctx->hdrs[i]->deleted = 0;
-    ctx->deleted = 0;
+    if (imap_sync_mailbox (ctx, purge) == -1)
+      return -1;
+    if (ctx->magic == M_IMAP && !purge)
+      mutt_message (_("%d kept."), ctx->msgcount);
   }
-
-  if (ctx->changed || ctx->deleted)
-  {
-    if (sync_mailbox (ctx) == -1)
-      return (-1);
-  }
-
-  if (move_messages)
-    mutt_message (_("%d kept, %d moved, %d deleted."),
-		  ctx->msgcount - ctx->deleted, read_msgs, ctx->deleted);
   else
-    mutt_message (_("%d kept, %d deleted."),
-		  ctx->msgcount - ctx->deleted, ctx->deleted);
+#endif
+  {
+    if (!purge)
+    {
+      for (i = 0; i < ctx->msgcount; i++)
+        ctx->hdrs[i]->deleted = 0;
+      ctx->deleted = 0;
+    }
 
-  if (ctx->msgcount == ctx->deleted &&
-      (ctx->magic == M_MMDF || ctx->magic == M_MBOX) &&
-      !mutt_is_spool(ctx->path) && !option (OPTSAVEEMPTY))
-    mx_unlink_empty (ctx->path);
+    if (ctx->changed || ctx->deleted)
+    {
+      if (sync_mailbox (ctx) == -1)
+        return -1;
+    }
+
+    if (move_messages)
+      mutt_message (_("%d kept, %d moved, %d deleted."),
+        ctx->msgcount - ctx->deleted, read_msgs, ctx->deleted);
+    else
+      mutt_message (_("%d kept, %d deleted."),
+        ctx->msgcount - ctx->deleted, ctx->deleted);
+
+    if (ctx->msgcount == ctx->deleted &&
+        (ctx->magic == M_MMDF || ctx->magic == M_MBOX) &&
+        !mutt_is_spool(ctx->path) && !option (OPTSAVEEMPTY))
+      mx_unlink_empty (ctx->path);
+  }
 
   mx_fastclose_mailbox (ctx);
 
@@ -976,6 +989,7 @@ void mx_update_tables(CONTEXT *ctx, int committing)
 int mx_sync_mailbox (CONTEXT *ctx)
 {
   int rc, i;
+  int purge = 1;
 
   if (ctx->dontwrite)
   {
@@ -1008,22 +1022,40 @@ int mx_sync_mailbox (CONTEXT *ctx)
     snprintf (buf, sizeof (buf), ctx->deleted == 1
 	     ? _("Purge %d deleted message?") : _("Purge %d deleted messages?"),
 	      ctx->deleted);
-    if ((rc = query_quadoption (OPT_DELETE, buf)) < 0)
+    if ((purge = query_quadoption (OPT_DELETE, buf)) < 0)
       return (-1);
-    else if (rc == M_NO)
+    else if (purge == M_NO)
     {
       if (!ctx->changed)
 	return 0; /* nothing to do! */
-      for (i = 0 ; i < ctx->msgcount ; i++)
-	ctx->hdrs[i]->deleted = 0;
-      ctx->deleted = 0;
+#ifdef USE_IMAP
+      /* let IMAP servers hold on to D flags */
+      if (ctx->magic != M_IMAP)
+#endif
+      {
+        for (i = 0 ; i < ctx->msgcount ; i++)
+          ctx->hdrs[i]->deleted = 0;
+        ctx->deleted = 0;
+      }
     }
   }
 
-  if ((rc = sync_mailbox (ctx)) == 0)
+#ifdef USE_IMAP
+  if (ctx->magic == M_IMAP)
+    rc = imap_sync_mailbox (ctx, purge);
+  else
+#endif
+  rc = sync_mailbox (ctx);
+  if (rc == 0)
   {
+#ifdef USE_IMAP
+    if (ctx->magic == M_IMAP && !purge)
+      mutt_message (_("%d kept."), ctx->msgcount);
+    else
+#endif
     mutt_message (_("%d kept, %d deleted."), ctx->msgcount - ctx->deleted,
-		  ctx->deleted);
+      ctx->deleted);
+
     sleep (1); /* allow the user time to read the message */
 
     if (ctx->msgcount == ctx->deleted &&
@@ -1035,8 +1067,12 @@ int mx_sync_mailbox (CONTEXT *ctx)
       return 0;
     }
 
-    mx_update_tables(ctx, 1);
-    mutt_sort_headers (ctx, 1); /* rethread from scratch */
+    /* if we haven't deleted any messages, we don't need to resort */
+    if (purge)
+    {
+      mx_update_tables(ctx, 1);
+      mutt_sort_headers (ctx, 1); /* rethread from scratch */
+    }
   }
 
   return (rc);
@@ -1137,15 +1173,39 @@ MESSAGE *mx_open_new_message (CONTEXT *dest, HEADER *hdr, int flags)
 }
 
 /* check for new mail */
-int mx_check_mailbox (CONTEXT *ctx, int *index_hint)
+int mx_check_mailbox (CONTEXT *ctx, int *index_hint, int lock)
 {
+  int rc;
+
   if (ctx)
   {
+    if (ctx->locked) lock = 0;
+
     switch (ctx->magic)
     {
       case M_MBOX:
       case M_MMDF:
-	return (mbox_check_mailbox (ctx, index_hint));
+
+	if (lock)
+	{
+	  mutt_block_signals ();
+	  if (mbox_lock_mailbox (ctx, 0, 0) == -1)
+	  {
+	    mutt_unblock_signals ();
+	    return M_LOCKED;
+	  }
+	}
+	
+	rc = mbox_check_mailbox (ctx, index_hint);
+
+	if (lock)
+	{
+	  mutt_unblock_signals ();
+	  mbox_unlock_mailbox (ctx);
+	}
+	
+	return rc;
+
 
       case M_MH:
       case M_MAILDIR:
